#!/bin/sh

error() {
	printf "%s\n" "$@" >&2
	exit 1
}

# pre checks
device-info -i secureboot \
	|| error "secureboot is not enabled"

abos-ctrl installer-setting secureboot \
	|| error "could not set secureboot enabled"


# self-extract to temporary dir
self=$(realpath "$0")
dir=$(mktemp -d /tmp/secureboot_make_installer.XXXXXXX) || exit
cd "$dir" || exit
# shellcheck disable=SC2064 ## expand now
trap "rm -rf $dir" EXIT
sed -e '1,/^BEGIN_ARCHIVE/d' "$self" | tar xv \
	|| error "self-extraction failed"

# run.
abos-ctrl make-installer \
    --verity "installer_verity_cert.pem" "installer_verity_key.pem" \
    --copy-sd "sd_copy" \
    --noprompt --output /target/mnt/installer.img \
	|| error "could not create installer disk image"


echo "Installer successfully created!" >&2
echo "Failing update on purpose to allow re-install" >&2

exit 1
# This must be the last line!
# shellcheck disable=SC2317 # (unreachable after exit)
BEGIN_ARCHIVE
